<?php

class Smart_SM_Connector
{

    private $avail_functions = array(
        'new_post' => 'NewPost',
        'edit_post' => 'EditPost',
        'get_post' => 'GetPost',
        'upload_image' => 'UploadImage',
        'get_terms' => 'GetTerms',
        'check_credentials' => 'CheckCredentialsPost',
        'list_post_types' => 'ListRegisteredPostTypes',
        'list_posts' => 'ListPosts',
    );

    function __construct()
    {

    }

    public static function ApiEcho( $val )
    {
        $output = serialize( $val );
        echo json_encode( array( 'type' => 'message', 'value' => $val ) );
        die();
    }

    public static function HandleError( $error )
    {
        echo json_encode( array( 'type' => 'error', 'value' => $error ) );
        die();
    }

    function ListRegisteredPostTypes()
    {
        $post_type_data = get_post_types( array( 'public' => true ), 'objects' );

        $post_types = array();

        foreach( $post_type_data as $key => $val )
        {
            $post_types[] = array(
                'slug' => $key,
                'name' => $val->labels->name
            );
        }

        $data = array(
            'post_types' => $post_types
        );

        $this->ApiEcho( $data );
    }

    function ListPosts()
    {
        $post_type = !empty( $_POST[ 'post_type' ] ) ? $_POST[ 'post_type' ] : 'post';

        $posts = get_posts(
            array(
                'post_type' => $post_type,
                'posts_per_page' => 100
            ) );

        foreach( $posts as $key => $val )
        {
            $posts[ $key ]->url       = get_the_permalink( $val->ID );
            $posts[ $key ]->thumbnail = wp_get_attachment_url( get_post_thumbnail_id( $val->ID ) );

            if( !$posts[ $key ]->thumbnail )
                unset( $posts[ $key ] );
        }

        $this->ApiEcho( $posts );
    }

    function CheckCredentialsPost()
    {
        $auth = $this->CheckCredentials( $_POST[ 'smc_hash' ], $_POST[ 'function' ] );
        $this->ApiEcho( $auth );
    }

    function CheckCredentials( $signature, $func )
    {
        if( !isset( $signature ) || !isset( $func ) )
        {
            $auth = false;
        }
        else
        {
            $hash_key = get_option( 'smc_hash' );

            if( $hash_key == $signature )
                $auth = true;
            else
                $auth = false;
        }
        return $auth;
    }

    function ProcessRequest()
    {
        global $current_user; //wp variable

        $auth = $this->CheckCredentials( isset( $_POST[ 'smc_hash' ] ) ? $_POST[ 'smc_hash' ] : '', isset( $_POST[ 'function' ] ) ? $_POST[ 'function' ] : '' );
        if( !$auth && isset( $_POST[ 'smc_hash' ] ) )
        {
            $this->HandleError( __( 'Authentication failed 2! You do not have permission to add this blog', 'sm-connector' ) );
        }
        if( isset( $_POST[ 'function' ] ) && isset( $this->avail_functions[ $_POST[ 'function' ] ] ) )
        {
            call_user_func( array( $this, ( $auth ? $this->avail_functions[ $_POST[ 'function' ] ] : $this->HandleError( __( 'Authentication failed! You do not have permission to add this blog', 'sm-connector' ) ) ) ) );
        }
        else
        {
            $this->HandleError( __( 'No predefined function is available for this call' ) );
        }
    }

    function EditPost()
    {
        //Read form data

        $custom_fields = unserialize( stripslashes( $_POST[ 'custom_fields' ] ) );

        $post_terms_names = unserialize( stripslashes( $_POST[ 'terms_names' ] ) );
        $post_category    = isset( $post_terms_names[ 'category' ] ) ? $post_terms_names[ 'category' ] : null;

        $post_tags = isset( $post_terms_names[ 'post_tag' ] ) ? $post_terms_names[ 'post_tag' ] : null;

        $post_featured_image = $_POST[ 'post_thumbnail' ];

        $res     = $this->EditExistingPost( $_POST, $custom_fields, $post_category, $post_tags, $post_featured_image );
        $created = $res[ 'success' ];
        if( $created != true )
        {
            $this->HandleError( $created );
        }
        $information              = array();
        $information[ 'post_id' ] = $res[ 'post_id' ];
        $information[ 'link' ]    = $res[ 'permalink' ];
        $this->ApiEcho( $information );
    }

    function EditExistingPost( $fields, $custom_fields, $post_category, $post_tags, $post_featured_image )
    {
        if( isset( $fields[ 'post_id' ] ) )
        {
            $fields[ 'ID' ] = $fields[ 'post_id' ];
        }
        wp_update_post( $fields );
        $permalink = get_permalink( $fields[ 'post_id' ] );
        if( is_array( $custom_fields ) && count( $custom_fields ) > 0 )
        {
            foreach( $custom_fields as $custom_field )
            {
                add_post_meta( $fields[ 'post_id' ], $custom_field[ 'key' ], serialize( $custom_field[ 'value' ] ) );
            }
        }
        include_once( ABSPATH . 'wp-admin/includes/taxonomy.php' ); //Contains wp_create_categories

        if( isset( $post_tags ) && count( $post_tags ) > 0 )
        {
            wp_set_post_tags( $fields[ 'post_id' ], $post_tags );
        }

        if( isset( $post_category ) && is_array( $post_category ) )
        {
            foreach( $post_category as $cat )
            {
                if( $id = category_exists( $cat ) )
                    $cat_ids[] = $id;
            }
            if( count( $cat_ids ) > 0 )
                wp_set_post_categories( $fields[ 'post_id' ], $cat_ids );
        }

        //If featured image exists - set it
        if( $post_featured_image != null )
        {
            update_post_meta( $fields[ 'post_id' ], '_thumbnail_id', $post_featured_image ); //Add the thumbnail to the post!
        }
        $ret[ 'success' ]   = true;
        $ret[ 'permalink' ] = $permalink;
        $ret[ 'post_id' ]   = $fields[ 'post_id' ];
        return $ret;
    }

    function NewPost()
    {
        //Read form data

        $custom_fields = unserialize( stripslashes( $_POST[ 'custom_fields' ] ) );

        $post_terms_names = unserialize( stripslashes( $_POST[ 'terms_names' ] ) );
        $post_category    = isset( $post_terms_names[ 'category' ] ) ? $post_terms_names[ 'category' ] : null;

        $post_tags = isset( $post_terms_names[ 'post_tag' ] ) ? $post_terms_names[ 'post_tag' ] : null;

        $post_featured_image = $_POST[ 'post_thumbnail' ];

        $res     = $this->CreatePost( $_POST, $custom_fields, $post_category, $post_tags, $post_featured_image );
        $created = $res[ 'success' ];
        if( $created != true )
        {
            $this->HandleError( $created );
        }
        $information              = array();
        $information[ 'post_id' ] = $res[ 'post_id' ];
        $information[ 'link' ]    = $res[ 'permalink' ];
        $this->ApiEcho( $information );
    }

    function CreatePost( $fields, $custom_fields, $post_category, $post_tags, $post_featured_image )
    {
        global $current_user;
        //Search for all the images added to the new post
        //some images have a href tag to click to navigate to the image.. we need to replace this too
        if( isset( $post_tags ) && $post_tags != '' )
            $fields[ 'tags_input' ] = $post_tags;
        //Save the post to the wp
        remove_filter( 'content_save_pre', 'wp_filter_post_kses' );  // to fix brake scripts or html
        $post_status             = $fields[ 'post_status' ];
        $fields[ 'post_status' ] = 'auto-draft';
        $new_post_id             = wp_insert_post( $fields, $wp_error );
        //Show errors if something went wrong
        if( is_wp_error( $wp_error ) )
        {
            return $wp_error->get_error_message();
        }
        if( empty( $new_post_id ) )
        {
            return 'Undefined error';
        }
        wp_update_post( array( 'ID' => $new_post_id, 'post_status' => $post_status ) );
        $permalink = get_permalink( $new_post_id );
        if( is_array( $custom_fields ) && count( $custom_fields ) > 0 )
        {
            foreach( $custom_fields as $custom_field )
            {
                add_post_meta( $new_post_id, $custom_field[ 'key' ], serialize( $custom_field[ 'value' ] ) );
            }
        }

        include_once( ABSPATH . 'wp-admin/includes/taxonomy.php' ); //Contains wp_create_categories

        if( isset( $post_tags ) && count( $post_tags ) > 0 )
        {
            wp_set_post_tags( $new_post_id, $post_tags );
        }

        if( isset( $post_category ) && is_array( $post_category ) )
        {
            foreach( $post_category as $cat )
            {
                if( $id = category_exists( $cat ) )
                    $cat_ids[] = $id;
            }
            if( count( $cat_ids ) > 0 )
                wp_set_post_categories( $new_post_id, $cat_ids );
        }

        //If featured image exists - set it
        if( $post_featured_image != null )
        {
            update_post_meta( $new_post_id, '_thumbnail_id', $post_featured_image ); //Add the thumbnail to the post!
        }
        $ret[ 'success' ]   = true;
        $ret[ 'permalink' ] = $permalink;
        $ret[ 'post_id' ]   = $new_post_id;
        return $ret;
    }

    function UploadImage( $image_path = '', $no_api_echo = false )
    {

        if( !isset( $image_path ) || $image_path == '' )
        {
            $image_path = isset( $_POST[ 'image_url' ] ) ? $_POST[ 'image_url' ] : '';
        }
        include_once( ABSPATH . 'wp-admin/includes/file.php' ); //Contains download_url
        //Download $img_url
        $temporary_file = download_url( $image_path );

        if( is_wp_error( $temporary_file ) )
        {
            $this->HandleError( 'There is an error with this method' );
        }
        else
        {

            $upload_dir     = wp_upload_dir();
            $local_img_path = $upload_dir[ 'path' ] . DIRECTORY_SEPARATOR . basename( $image_path ); //Local name
            $local_img_url  = $upload_dir[ 'url' ] . '/' . basename( $image_path );
            $moved          = @rename( $temporary_file, $local_img_path );
            if( $moved )
            {

                $wp_filetype = wp_check_filetype( basename( $image_path ), null ); //Get the filetype to set the mimetype
                $attachment  = array(
                    'post_mime_type' => $wp_filetype[ 'type' ],
                    'post_title' => preg_replace( '/\.[^.]+$/', '', basename( $image_path ) ),
                    'post_content' => '',
                    'post_status' => 'inherit'
                );
                $attach_id   = wp_insert_attachment( $attachment, $local_img_path ); //Insert the image in the database
                require_once( ABSPATH . 'wp-admin/includes/image.php' );
                $attach_data = wp_generate_attachment_metadata( $attach_id, $local_img_path );
                wp_update_attachment_metadata( $attach_id, $attach_data ); //Update generated metadata
                if( !$no_api_echo )
                {
                    $this->ApiEcho( array( 'id' => $attach_id, 'url' => $local_img_url ) );
                }
                else
                {
                    return array( 'id' => $attach_id, 'url' => $local_img_url );
                }
            }
        }
        if( file_exists( $temporary_file ) )
        {
            unlink( $temporary_file );
        }
        return null;
    }

    function GetTerms()
    {
        $taxonomy = ( $_POST[ 'taxonomy' ] );
        $rslt     = get_terms( taxonomy_exists( $taxonomy ) ? $taxonomy : 'category', 'hide_empty=0' );
        $this->ApiEcho( serialize( $rslt ) );
    }

    function set_terms()
    {
        $id       = ( $_POST[ 'id' ] );
        $terms    = ( $_POST[ 'terms' ] );
        $taxonomy = ( $_POST[ 'taxonomy' ] );

        if( trim( $terms ) != '' )
        {
            $terms = explode( ',', $terms );
            if( count( $terms ) > 0 )
            {
                wp_set_object_terms( $id, array_map( 'intval', $terms ), taxonomy_exists( $taxonomy ) ? $taxonomy : 'category' );
            }
        }
    }

    function DebugIt()
    {
        $args = func_get_args();

        if( count( $args ) > 0 )
        {
            echo "\n<pre>";

            foreach( $args as $key => $val )
            {
                echo "\n\n========== Degugging Item " . ( $key + 1 ) . " ==========\n\n";
                var_dump( $val );
            }

            echo "\n\n========== END OF DEBUGGING ==========";
            echo "\n</pre>\n\n";
        }
    }
}
